@@ -332,10 +332,10 @@ load_templates_tsv <-
 
     # read columns in files
     templates <- lapply(template_file, function(x) {
-      data.table::fread(x,
-                        sep = "\t",
-                        header = TRUE,
-                        na.strings = c("", "NA")) %>% stats::na.omit()
+      stats::na.omit(data.table::fread(x,
+                                       sep = "\t",
+                                       header = TRUE,
+                                       na.strings = c("", "NA")))
     })
     names(templates) <- template_filename
     # check WellRow/WellColumn is present in each df
@@ -852,11 +852,12 @@ load_results_EnVision_new <- function(results_file, headers = gDRutils::get_env_
     }
     barcode_line_idx <- barcode_header_idx[1] + 1
     barcode_line <- lines[barcode_line_idx]
-    barcode <- strsplit(barcode_line, ";")[[1]][1]
+    barcode <- strsplit(barcode_line, ";|,")[[1]][1]
 
-    data_header_idx <- grep("^;1;2;3", lines)
+    data_header_idx <- grep("^[;,]1[;,]2[;,]3", lines)
+    
     if (length(data_header_idx) == 0) {
-      stop(sprintf("Could not find data matrix header (e.g., ';1;2;3...') in file: %s", current_file))
+      stop(sprintf("Could not find data matrix header (e.g., ';1;2;3...' or ',1,2,3...') in file: %s", current_file))
     }
     data_start_line <- data_header_idx[1]
 
